@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.13_01';
+our $VERSION = '0.13_02';
 
 use AnyEvent::RipeRedis;
 use AnyEvent::RipeRedis::Error;
@@ -581,7 +581,7 @@ sub _prepare {
       my $err   = shift;
 
       if ( defined $err ) {
-        $self->{on_error}->( $err, $reply );
+        $self->{on_error}->($err);
         return;
       }
     };
@@ -950,18 +950,30 @@ L<http://redis.io/topics/cluster-spec>
     reconnect_interval => 5,
 
     on_node_connect => sub {
+      my $host = shift;
+      my $port = shift;
+
       # handling...
     },
 
     on_node_disconnect => sub {
+      my $host = shift;
+      my $port = shift;
+
       # handling...
     },
 
     on_node_error => sub {
+      my $err = shift;
+      my $host = shift;
+      my $port = shift;
+
       # error handling...
     },
 
     on_error => sub {
+      my $err = shift;
+
       # error handling...
     },
   );
